- `Python doc: Reading and writing files <https://docs.python.org/3/tutorial/inputoutput.html#reading-and-writing-files>`_
- `PEP 343 <https://peps.python.org/pep-0343/>`_
- `Context managers in Python <https://johnlekberg.com/blog/2020-10-11-ctx-manage.html>`_ by John Lekberg
- `Rationale <https://stackoverflow.com/a/73181877/2519059>`_
